@@ -84,6 +84,7 @@ import javax.swing.event.TableModelEvent;
 import javax.swing.event.TableModelListener;
 import javax.swing.table.TableColumnModel;
 import org.astrogrid.samp.client.DefaultClientProfile;
+import uk.ac.starlink.auth.AuthManager;
 import uk.ac.starlink.plastic.PlasticUtils;
 import uk.ac.starlink.table.DescribedValue;
 import uk.ac.starlink.table.RowRunner;
@@ -134,7 +135,6 @@ import uk.ac.starlink.util.gui.StringPaster;
 import uk.ac.starlink.vo.DalLoader;
 import uk.ac.starlink.vo.DalTableLoadDialog;
 import uk.ac.starlink.vo.SkyDalTableLoadDialog;
-import uk.ac.starlink.vo.SkyPositionEntry;
 
 /**
  * Main window providing user control of the TOPCAT application.
@@ -231,6 +231,7 @@ public class ControlWindow extends AuxWindow
     private final Action cdsmatchAct_;
     private final ModelViewAction datalinkAct_;
     private final Action logAct_;
+    private final Action authResetAct_;
     private final Action[] matchActs_;
     private final ShowAction[] showActs_;
     private final ModelViewAction[] viewActs_;
@@ -370,6 +371,11 @@ public class ControlWindow extends AuxWindow
                              + "CDS VizieR or SIMBAD services" );
         logAct_ = new ControlAction( "View Log", ResourceIcon.LOG,
                                      "Display the log of events" );
+        authResetAct_ =
+            new ControlAction( "Reset Authentication", ResourceIcon.RESET_AUTH,
+                               "Clear any authentication credentials "
+                             + "entered so far in the GUI" );
+                                         
         readAct_.setEnabled( canRead_ );
         saveAct_.setEnabled( canWrite_ );
         logAct_.setEnabled( LogHandler.getInstance() != null );
@@ -442,6 +448,7 @@ public class ControlWindow extends AuxWindow
             new Plot2WindowAction( PlotWindowType.SKY ),
             new Plot2WindowAction( PlotWindowType.CUBE ),
             new Plot2WindowAction( PlotWindowType.SPHERE ),
+            new Plot2WindowAction( PlotWindowType.MATRIX ),
             new Plot2WindowAction( PlotWindowType.TIME ),
         };
         Action[] morePlot2Acts = new Action[] {
@@ -620,6 +627,7 @@ public class ControlWindow extends AuxWindow
         }
         fileMenu.insertSeparator( fileMenuPos++ );
         fileMenu.insert( logAct_, fileMenuPos++ );
+        fileMenu.insert( authResetAct_, fileMenuPos++ );
         fileMenu.insertSeparator( fileMenuPos++ );
 
         /* Add a menu for the table views. */
@@ -803,6 +811,15 @@ public class ControlWindow extends AuxWindow
         return runner_;
     }
 
+    /**
+     * Returns an action that will reset all authentication contexts.
+     *
+     * @return   auth reset action
+     */
+    public Action getAuthResetAction() {
+        return authResetAct_;
+    }
+
     /**
      * Adds a table to this windows list.
      * Following this, a user will be able to do TOPCATty things with
@@ -1514,6 +1531,17 @@ public class ControlWindow extends AuxWindow
                 }
             }
         }
+
+        /* Cone Search 1.03 Section 2 paragraph 3 requires a non-DALI
+         * variant. */
+        for ( DescribedValue dval : table.getParameters() ) {
+            ValueInfo info = dval.getInfo();
+            if ( "Error".equals( info.getName() ) ) {
+                Object vobj = dval.getValue();
+                return vobj instanceof String ? ((String) vobj).trim()
+                                              : "Error";
+            }
+        }
         return "";
     }
 
@@ -1641,8 +1669,11 @@ public class ControlWindow extends AuxWindow
             else if ( this == logAct_ ) {
                 LogHandler.getInstance().showWindow( ControlWindow.this );
             }
+            else if ( this == authResetAct_ ) {
+                AuthManager.getInstance().clear();
+            }
             else {
-                throw new AssertionError();
+                assert false;
             }
         }
     }
