@@ -362,12 +362,19 @@ public class LinkRowPanel extends JPanel {
          * Constructor.
          */
         public AccessUrlLinkDisplay() {
-            infoStack_ = new InfoStack( new LinkColMap.ColDef<?>[] {
-                LinkColMap.COL_ACCESSURL,
-                LinkColMap.COL_CONTENTTYPE,
-                LinkColMap.COL_CONTENTLENGTH,
-                LinkColMap.COL_DESCRIPTION,
-                LinkColMap.COL_SEMANTICS,
+            infoStack_ = new InfoStack( new InfoStack.Item[] {
+                new InfoStack.Item( "Access URL",
+                                    LinkColMap.COL_ACCESSURL ),
+                new InfoStack.Item( "Content Type",
+                                    LinkColMap.COL_CONTENTTYPE,
+                                    LinkColMap.COL_CONTENTQUALIFIER ),
+                new InfoStack.Item( "Content Length",
+                                    LinkColMap.COL_CONTENTLENGTH ),
+                new InfoStack.Item( "Description",
+                                    LinkColMap.COL_DESCRIPTION ),
+                new InfoStack.Item( "Semantics",
+                                    LinkColMap.COL_SEMANTICS,
+                                    LinkColMap.COL_LOCALSEMANTICS ),
             } );
             JComponent box = Box.createVerticalBox();
             box.add( infoStack_ );
@@ -401,8 +408,24 @@ public class LinkRowPanel extends JPanel {
             else {
                 url = null;
             }
-            String ctype = colMap.getContentType( row );
-            urlPanel_.configure( url, ctype, null );
+            final URL url0 = url;
+            final String ctype = colMap.getContentType( row );
+            final String cqual = colMap.getContentQualifier( row );
+            ResourceInfo resInfo = new ResourceInfo() {
+                public URL getUrl() {
+                    return url0;
+                }
+                public String getContentType() {
+                    return ctype;
+                }
+                public String getContentQualifier() {
+                    return cqual;
+                }
+                public String getStandardId() {
+                    return null;
+                }
+            };
+            urlPanel_.configureResource( resInfo );
         }
         public boolean isAutoInvoke() {
             return urlPanel_.isAutoInvoke();
@@ -431,10 +454,15 @@ public class LinkRowPanel extends JPanel {
          * Constructor.
          */
         ServiceLinkDisplay() {
-            infoStack_ = new InfoStack( new LinkColMap.ColDef<?>[] {
-                LinkColMap.COL_CONTENTTYPE,
-                LinkColMap.COL_DESCRIPTION,
-                LinkColMap.COL_SEMANTICS,
+            infoStack_ = new InfoStack( new InfoStack.Item[] {
+                new InfoStack.Item( "Content Type",
+                                    LinkColMap.COL_CONTENTTYPE,
+                                    LinkColMap.COL_CONTENTQUALIFIER ),
+                new InfoStack.Item( "Description",
+                                    LinkColMap.COL_DESCRIPTION ),
+                new InfoStack.Item( "Semantics",
+                                    LinkColMap.COL_SEMANTICS,
+                                    LinkColMap.COL_LOCALSEMANTICS ),
             } );
             standardIdField_ = infoStack_.addField( "Standard ID" );
             resourceIdField_ = infoStack_.addField( "Resource ID" );
@@ -496,7 +524,7 @@ public class LinkRowPanel extends JPanel {
             }
             else {
                 uiPanel = createExcusePanel( excuseMsg );
-                urlPanel_.configure( null, null, null );
+                urlPanel_.configureResource( null );
             }
             uiPanel_ = uiPanel;
         }
@@ -560,7 +588,11 @@ public class LinkRowPanel extends JPanel {
             urlPanel_ = urlPanel;
             ServiceDescriptor descriptor = invoker.getServiceDescriptor();
             standardId_ = descriptor.getStandardId();
-            contentType_ = colMap.getContentType( row );
+            String contentType = colMap.getContentType( row );
+            if ( contentType == null || contentType.trim().length() == 0 ) {
+                contentType = descriptor.getContentType();
+            }
+            contentType_ = contentType;
             Map<ServiceParam,String> suppliedMap =
                 new HashMap<ServiceParam,String>();
             suppliedMap.putAll( invoker.getFixedParamMap() );
@@ -584,7 +616,21 @@ public class LinkRowPanel extends JPanel {
         private void configureUrl() {
             Map<ServiceParam,String> valueMap = paramPanel_.getValueMap();
             URL url = invoker_.completeUrl( valueMap );
-            urlPanel_.configure( url, contentType_, standardId_ );
+            ResourceInfo resInfo = new ResourceInfo() {
+                public URL getUrl() {
+                    return url;
+                }
+                public String getContentType() {
+                    return contentType_;
+                }
+                public String getContentQualifier() {
+                    return null;
+                }
+                public String getStandardId() {
+                    return standardId_;
+                }
+            };
+            urlPanel_.configureResource( resInfo );
         }
     }
 
@@ -592,19 +638,18 @@ public class LinkRowPanel extends JPanel {
      * LabelledComponentStack subclass that displays LinkColMap items.
      */
     private static class InfoStack extends LabelledComponentStack {
-        final Map<LinkColMap.ColDef<?>,JTextField> fieldMap_;
+        private final Map<Item,JTextField> itemMap_;
 
         /**
          * Constructor.
          *
-         * @param  cols  items to display
+         * @param  items  items to display
          */
-        public InfoStack( LinkColMap.ColDef<?>[] cols ) {
+        public InfoStack( Item[] items ) {
             super();
-            fieldMap_ = new LinkedHashMap<LinkColMap.ColDef<?>,JTextField>();
-            for ( LinkColMap.ColDef<?> col : cols ) {
-                JTextField field = addField( col.getName() );
-                fieldMap_.put( col, field );
+            itemMap_ = new HashMap<Item,JTextField>();
+            for ( Item item : items ) {
+                itemMap_.put( item, addField( item.name_ ) );
             }
         }
 
@@ -629,14 +674,42 @@ public class LinkRowPanel extends JPanel {
          * @param  row    row vector from links document
          */
         public void configureForRow( LinkColMap colMap, Object[] row ) {
-            for ( Map.Entry<LinkColMap.ColDef<?>,JTextField> entry :
-                  fieldMap_.entrySet() ) {
-                LinkColMap.ColDef<?> col = entry.getKey();
+            for ( Map.Entry<Item,JTextField> entry : itemMap_.entrySet() ) {
+                LinkColMap.ColDef<?>[] cols = entry.getKey().cols_;
                 JTextField field = entry.getValue();
-                Object value = colMap.getValue( col, row );
-                field.setText( value == null ? null : value.toString() );
+                StringBuffer sbuf = new StringBuffer();
+                for ( LinkColMap.ColDef<?> col : cols ) {
+                    Object value = colMap.getValue( col, row );
+                    String sval = value == null ? null : value.toString();
+                    if ( sval != null && sval.trim().length() > 0 ) {
+                        if ( sbuf.length() > 0 ) {
+                            sbuf.append( "; " );
+                        }
+                        sbuf.append( sval );
+                    }
+                }
+                field.setText( sbuf.toString() );
                 field.setCaretPosition( 0 );
             }
         }
+
+        /**
+         * Defines the content of a row in this stack.
+         */
+        private static class Item {
+            final String name_;
+            final LinkColMap.ColDef<?>[] cols_;
+
+            /**
+             * Constructor.
+             *
+             * @param  name  text label for information.
+             * @param  cols  array of datalink columns to use for content
+             */
+            Item( String name, LinkColMap.ColDef<?> ... cols ) {
+                name_ = name;
+                cols_ = cols;
+            }
+        }
     }
 }
