@@ -86,6 +86,7 @@ public class ResourceIcon implements Icon {
         ESA_LOGO = makeIcon( "esa48.png" ),
         VIZIER_LOGO = makeIcon( "vizier_logo.png" ),
         EU_LOGO = makeIcon( "eu48.png" ),
+        EUROPLANET_LOGO = makeIcon( "europlanet48.png" ),
 
         /* Generic actions. */
         CLOSE = makeIcon( "multiply4.png"),
@@ -121,6 +122,7 @@ public class ResourceIcon implements Icon {
         SCROLLER = makeIcon( "scroll2.png" ),
         PARALLEL = makeIcon( "parallel1.png" ),
         STILTS = makeIcon( "stilts.png" ),
+        EDIT = makeIcon( "pencil.png" ),
 
         /* Windows. */
         CONTROL = makeIcon( "controlw.png" ),
@@ -198,6 +200,7 @@ public class ResourceIcon implements Icon {
         MOVE_DOWN = makeIcon( "Down2.png" ),
         EQUATION = makeIcon( "xeq.png" ),
         EXPLODE = makeIcon( "explode.png" ),
+        COLLAPSE = makeIcon( "collapse.png" ),
         ADDSKY = makeIcon( "addsky1.png" ),
         COLOR_LOG = makeIcon( "logred2.png" ),
         XLOG = makeIcon( "xlog.png" ),
@@ -258,6 +261,7 @@ public class ResourceIcon implements Icon {
         MEASURE = makeIcon( "measure.png" ),
         LOCK = makeIcon( "lock2.png" ),
         QAPPROX = makeIcon( "qapprox.png" ),
+        RESET_AUTH = makeIcon( "rublock.png" ),
 
         /* Plot2 icons. */
         UP_DOWN = makeIcon( "updown8.png" ),
@@ -268,10 +272,12 @@ public class ResourceIcon implements Icon {
         PLOT_HISTO = makeIcon( "histoplot.png" ),
         PLOT_AREA = makeIcon( "areaplot.png" ),
         PLOT_VECTOR = makeIcon( "vectorplot.png" ),
+        PLOT_MATRIX = makeIcon( "pm1.png" ),
         PLOT2_PLANE = makeIcon( "plot2plane.png" ),
         PLOT2_SKY = makeIcon( "plot2sky.png" ),
         PLOT2_CUBE = makeIcon( "plot2cube.png" ),
         PLOT2_SPHERE = makeIcon( "plot2sphere.png" ),
+        PLOT2_MATRIX = makeIcon( "plot2matrix.png" ),
         PLOT2_TIME = makeIcon( "plot2time.png" ),
         PLOT2_HISTOGRAM = makeIcon( "plot2hist.png" ),
         HISTOBARS = makeIcon( "histobars.png" ),
@@ -728,6 +734,7 @@ public class ResourceIcon implements Icon {
         putMap( nameMap, "ADD_PLOT_DATA", toAddIcon( PLOT_DATA ) );
         putMap( nameMap, "ADD_PLOT_PAIR", toAddIcon( PLOT_PAIR ) );
         putMap( nameMap, "ADD_PLOT_QUAD", toAddIcon( PLOT_QUAD ) );
+        putMap( nameMap, "ADD_PLOT_MATRIX", toAddIcon( PLOT_MATRIX ) );
         putMap( nameMap, "ADD_PLOT_AREA", toAddIcon( PLOT_AREA ) );
         putMap( nameMap, "ADD_PLOT_HISTO", toAddIcon( PLOT_HISTO ) );
         putMap( nameMap, "ADD_PLOT_HEALPIX", toAddIcon( TTRI.PLOT_HEALPIX ) );
