@@ -1,6 +1,5 @@
 package uk.ac.starlink.topcat;
 
-import gnu.jel.CompilationException;
 import java.awt.Component;
 import java.awt.event.ActionEvent;
 import java.awt.event.KeyEvent;
@@ -53,6 +52,7 @@ public class SubsetWindow extends AuxWindow implements ListDataListener {
     private final Action tocolAct;
     private final Action highlightAct;
     private final Action countAct;
+    private final Action editAct;
     private final Action invertAct;
     private final Action sampleAct;
     private final Action headAct;
@@ -150,13 +150,19 @@ public class SubsetWindow extends AuxWindow implements ListDataListener {
                                      "(Re)count the number of rows in each " +
                                      "subset" );
 
-        /* Action for highlighting selectd subset. */
+        /* Action for highlighting selected subset. */
         highlightAct = new SubsetAction( "Highlight subset",
                                          ResourceIcon.HIGHLIGHT,
                                          "Highlight the selected subset by "
                                        + "marking its rows in the table window "
                                        + "and ensuring it's visible in plots" );
 
+        /* Action for editing selected subset. */
+        editAct = new SubsetAction( "Edit subset", ResourceIcon.EDIT,
+                                    "Show a window that lets you edit the "
+                                  + "expression and name for "
+                                  + "the selected subset" );
+
         /* Action for producing inverse subset. */
         invertAct = new SubsetAction( "Invert subset", ResourceIcon.INVERT,
                                       "Create new subset complementary to " +
@@ -221,6 +227,7 @@ public class SubsetWindow extends AuxWindow implements ListDataListener {
                 }
                 removeAct.setEnabled( hasSelection && ! isAllSelected );
                 tocolAct.setEnabled( hasUniqueSelection );
+                editAct.setEnabled( hasUniqueSelection );
                 invertAct.setEnabled( hasUniqueSelection );
                 highlightAct.setEnabled( hasUniqueSelection );
                 if ( subsetTransmitter != null ) {
@@ -271,6 +278,7 @@ public class SubsetWindow extends AuxWindow implements ListDataListener {
         getToolBar().add( sampleAct );
         getToolBar().add( headAct );
         getToolBar().add( tailAct );
+        getToolBar().add( editAct );
         getToolBar().add( invertAct );
         getToolBar().add( classifyAct );
         getToolBar().add( removeAct );
@@ -290,6 +298,7 @@ public class SubsetWindow extends AuxWindow implements ListDataListener {
         subsetsMenu.add( sampleAct );
         subsetsMenu.add( headAct );
         subsetsMenu.add( tailAct );
+        subsetsMenu.add( editAct );
         subsetsMenu.add( invertAct );
         subsetsMenu.add( classifyAct );
         subsetsMenu.add( removeAct );
@@ -398,45 +407,16 @@ public class SubsetWindow extends AuxWindow implements ListDataListener {
                 return getSubset( irow ) instanceof SyntheticRowSubset;
             }
             public void setValue( int irow, Object value ) {
-                String expr = value.toString();
-                SyntheticRowSubset rset =
-                   (SyntheticRowSubset) getSubset( irow );
-                if ( expr != null && expr.equals( rset.getExpression() ) ) {
-                    return;
+                String expr = (String) value;
+                SubsetQueryWindow qwin =
+                    SubsetQueryWindow
+                   .editSubsetDialog( tcModel, SubsetWindow.this, irow );
+                qwin.getExpressionField().setText( expr );
+                if ( qwin.perform() ) {
+                    qwin.dispose();
                 }
-                int rsetId = subsets.indexToId( irow );
-                if ( TopcatJELUtils
-                    .isSubsetReferenced( tcModel, rsetId, expr ) ) {
-                    String[] msg = new String[] {
-                        "Recursive subset expression disallowed:",
-                        "\"" + expr + "\"" +
-                        " directly or indirectly references subset " +
-                        rset.getName(),
-                    };
-                    JOptionPane.showMessageDialog( SubsetWindow.this, msg,
-                                                   "Expression Error",
-                                                   JOptionPane.ERROR_MESSAGE );
-                    return;
-                }
-                try {
-                    rset.setExpression( value.toString() );
-                }
-                catch ( CompilationException e ) {
-                    String[] msg = new String[] {
-                        "Syntax error in algebraic subset expression \""
-                        + value + "\":",
-                        e.getMessage(),
-                    };
-                    JOptionPane.showMessageDialog( SubsetWindow.this, msg,
-                                                   "Expression Syntax Error",
-                                                   JOptionPane.ERROR_MESSAGE );
-                    return;
-                }
-                subsetCounts.remove( rset );
-                subsets.set( irow, rset );
-                if ( tcModel.getSubsetSelectionModel().getSelectedItem()
-                     == rset ) {
-                    tcModel.getViewModel().setSubset( rset );
+                else {
+                    qwin.setVisible( true );
                 }
             }
         };
@@ -618,7 +598,7 @@ public class SubsetWindow extends AuxWindow implements ListDataListener {
         public void actionPerformed( ActionEvent evt ) {
             Component parent = SubsetWindow.this;
             if ( this == addAct ) {
-                new SyntheticSubsetQueryWindow( tcModel, parent )
+                SubsetQueryWindow.newSubsetDialog( tcModel, parent )
                .setVisible( true );
             }
 
@@ -635,7 +615,8 @@ public class SubsetWindow extends AuxWindow implements ListDataListener {
 
             else if ( this == tocolAct ) {
                 SyntheticColumnQueryWindow colwin =
-                    new SyntheticColumnQueryWindow( tcModel, -1, parent );
+                    SyntheticColumnQueryWindow
+                   .newColumnDialog( tcModel, -1, parent );
                 int irow = toUnsortedIndex( jtab.getSelectedRow() );
                 colwin.setExpression( getSubsetID( irow ) );
                 colwin.setName( getSubsetName( irow ) );
@@ -656,6 +637,13 @@ public class SubsetWindow extends AuxWindow implements ListDataListener {
                 sc.start();
             }
 
+            else if ( this == editAct ) {
+                int irow = toUnsortedIndex( jtab.getSelectedRow() );
+                SubsetQueryWindow
+               .editSubsetDialog( tcModel, SubsetWindow.this, irow )
+               .setVisible( true );
+            }
+
             else if ( this == invertAct ) {
                 int irow = toUnsortedIndex( jtab.getSelectedRow() );
                 subsets.add( new InverseRowSubset( getSubset( irow ) ) );
