@@ -2,6 +2,7 @@ package uk.ac.starlink.topcat;
 
 import gnu.jel.CompilationException;
 import java.awt.Component;
+import java.util.function.Consumer;
 import javax.swing.AbstractSpinnerModel;
 import javax.swing.JComboBox;
 import javax.swing.JOptionPane;
@@ -20,76 +21,76 @@ import uk.ac.starlink.table.gui.UCDSelector;
  * A dialogue window which queries the user for the characteristics of a
  * new column and then appends it to the table.
  */
-public class SyntheticColumnQueryWindow extends QueryWindow {
+public abstract class SyntheticColumnQueryWindow extends QueryWindow {
 
-    private final TopcatModel tcModel;
-    private final TableColumnModel columnModel;
-    private JTextField nameField;
-    private JTextField unitField;
-    private JTextField descriptionField;
-    private JTextField expressionField;
-    private JComboBox<Class<?>> typeField;
-    private UCDSelector ucdField;
-    private ColumnIndexSpinner indexSpinner;
+    private final TopcatModel tcModel_;
+    private final TableColumnModel columnModel_;
+    private JTextField nameField_;
+    private JTextField unitField_;
+    private JTextField descriptionField_;
+    private JTextField expressionField_;
+    private JComboBox<Class<?>> typeField_;
+    private UCDSelector ucdField_;
+    private ColumnIndexSpinner indexSpinner_;
 
     /**
-     * Constructs a new query window, which on user completion will 
-     * append a new column to the viewer <tt>tableviewer</tt> at the
-     * column index <tt>insertIndex</tt>.
+     * Constructor.
      *
      * @param   tcModel      model containing the table data
-     * @param   insertIndex  the postion for the new column
+     * @param   insertIndex  the default position for the new column
+     * @param   isAdd        true for adding a new column,
+     *                       false to edit an existing one
      * @param   parent       the parent window for this dialogue (used for
      *                       window positioning)
      */
-    public SyntheticColumnQueryWindow( TopcatModel tcModel,
-                                       int insertIndex, Component parent ) {
+    private SyntheticColumnQueryWindow( TopcatModel tcModel, int insertIndex,
+                                        boolean isAdd, Component parent ) {
         super( "Define Synthetic Column", parent );
-        this.tcModel = tcModel;
-        this.columnModel = tcModel.getColumnModel();
+        tcModel_ = tcModel;
+        columnModel_ = tcModel.getColumnModel();
         LabelledComponentStack stack = getStack();
 
         /* Name field. */
-        nameField = new JTextField();
-        stack.addLine( "Name", nameField );
+        nameField_ = new JTextField();
+        stack.addLine( "Name", nameField_ );
 
         /* Expression field. */
-        expressionField = new JTextField();
-        stack.addLine( "Expression", expressionField );
+        expressionField_ = new JTextField();
+        stack.addLine( "Expression", expressionField_ );
 
         /* Units field. */
-        unitField = new JTextField();
-        stack.addLine( "Units", unitField );
+        unitField_ = new JTextField();
+        stack.addLine( "Units", unitField_ );
 
         /* Description field. */
-        descriptionField = new JTextField();
-        stack.addLine( "Description", descriptionField );
+        descriptionField_ = new JTextField();
+        stack.addLine( "Description", descriptionField_ );
 
         /* Class selector. */
-        typeField = new JComboBox<Class<?>>();
-        typeField.addItem( null );
-        typeField.addItem( byte.class );
-        typeField.addItem( short.class );
-        typeField.addItem( int.class );
-        typeField.addItem( long.class );
-        typeField.addItem( float.class );
-        typeField.addItem( double.class );
-        typeField.setRenderer( new ClassComboBoxRenderer( "(auto)" ) );
-        typeField.setSelectedIndex( 0 );
+        typeField_ = new JComboBox<Class<?>>();
+        typeField_.addItem( null );
+        typeField_.addItem( byte.class );
+        typeField_.addItem( short.class );
+        typeField_.addItem( int.class );
+        typeField_.addItem( long.class );
+        typeField_.addItem( float.class );
+        typeField_.addItem( double.class );
+        typeField_.setRenderer( new ClassComboBoxRenderer( "(auto)" ) );
+        typeField_.setSelectedIndex( 0 );
 
         // Don't add this option for now - it's not that useful, since
         // narrowing conversions cause an error in any case, which, 
         // while sensible, is not what the user is going to expect.
-        // stack.addLine( "Numeric Type", typeField );
+        // stack.addLine( "Numeric Type", typeField_ );
 
         /* UCD field. */
-        ucdField = new UCDSelector();
-        stack.addLine( "UCD", ucdField );
+        ucdField_ = new UCDSelector();
+        stack.addLine( "UCD", ucdField_ );
 
         /* Index field. */
-        indexSpinner = new ColumnIndexSpinner( columnModel );
-        indexSpinner.setColumnIndex( insertIndex );
-        stack.addLine( "Index", indexSpinner );
+        indexSpinner_ = new ColumnIndexSpinner( columnModel_, isAdd );
+        indexSpinner_.setColumnIndex( insertIndex );
+        stack.addLine( "Index", indexSpinner_ );
 
         /* Add tools. */
         getToolBar().add( MethodWindow.getWindowAction( this, false ) );
@@ -105,7 +106,7 @@ public class SyntheticColumnQueryWindow extends QueryWindow {
      * @return  name
      */
     public String getColumnName() {
-        return nameField.getText();
+        return nameField_.getText();
     }
 
     /**
@@ -114,7 +115,7 @@ public class SyntheticColumnQueryWindow extends QueryWindow {
      * @param  name new contents of the name field
      */
     public void setColumnName( String name ) {
-        nameField.setText( name );
+        nameField_.setText( name );
     }
 
     /**
@@ -123,7 +124,7 @@ public class SyntheticColumnQueryWindow extends QueryWindow {
      * @return  units
      */
     public String getUnit() {
-        return unitField.getText();
+        return unitField_.getText();
     }
 
     /**
@@ -132,7 +133,7 @@ public class SyntheticColumnQueryWindow extends QueryWindow {
      * @param  units  unit string
      */
     public void setUnit( String units ) {
-        unitField.setText( units );
+        unitField_.setText( units );
     }
 
     /**
@@ -141,7 +142,7 @@ public class SyntheticColumnQueryWindow extends QueryWindow {
      * @return  description
      */
     public String getDescription() {
-        return descriptionField.getText();
+        return descriptionField_.getText();
     }
 
     /**
@@ -150,7 +151,7 @@ public class SyntheticColumnQueryWindow extends QueryWindow {
      * @param   desc  description string
      */
     public void setDescription( String desc ) {
-        descriptionField.setText( desc );
+        descriptionField_.setText( desc );
     }
 
     /**
@@ -159,7 +160,7 @@ public class SyntheticColumnQueryWindow extends QueryWindow {
      * @return  expression
      */
     public String getExpression() {
-        return expressionField.getText();
+        return expressionField_.getText();
     }
 
     /**
@@ -168,7 +169,7 @@ public class SyntheticColumnQueryWindow extends QueryWindow {
      * @param   expr   new contents of the expression field
      */
     public void setExpression( String expr ) {
-        expressionField.setText( expr );
+        expressionField_.setText( expr );
     }
 
     /**
@@ -177,7 +178,7 @@ public class SyntheticColumnQueryWindow extends QueryWindow {
      * @return  UCD identifier
      */
     public String getUCD() {
-        return ucdField.getID();
+        return ucdField_.getID();
     }
 
     /**
@@ -186,7 +187,7 @@ public class SyntheticColumnQueryWindow extends QueryWindow {
      * @param  ucd  UCD string
      */
     public void setUCD( String ucd ) {
-        ucdField.setID( ucd );
+        ucdField_.setID( ucd );
     }
 
     /**
@@ -196,7 +197,7 @@ public class SyntheticColumnQueryWindow extends QueryWindow {
      * @param   clazz  forced expression type, or null
      */
     public void setExpressionType( Class<?> clazz ) {
-        typeField.setSelectedItem( clazz );
+        typeField_.setSelectedItem( clazz );
     }
 
     /**
@@ -206,7 +207,7 @@ public class SyntheticColumnQueryWindow extends QueryWindow {
      * @return  forced expression type, or null
      */
     public Class<?> getExpressionType() {
-        return (Class<?>) typeField.getSelectedItem();
+        return (Class<?>) typeField_.getSelectedItem();
     }
 
     /**
@@ -215,7 +216,7 @@ public class SyntheticColumnQueryWindow extends QueryWindow {
      * @return  index
      */
     public int getIndex() {
-        return indexSpinner.getColumnIndex();
+        return indexSpinner_.getColumnIndex();
     }
 
     /**
@@ -243,7 +244,7 @@ public class SyntheticColumnQueryWindow extends QueryWindow {
             info.setUnitString( unit );
         }
         try {
-            return new SyntheticColumn( tcModel, info, expr, null );
+            return new SyntheticColumn( tcModel_, info, expr, null );
         }
         catch ( CompilationException e ) {
             String[] msg = new String[] {
@@ -257,20 +258,117 @@ public class SyntheticColumnQueryWindow extends QueryWindow {
     }
 
     /**
-     * Invokes {@link #makeColumn} and adds the resulting column to the 
-     * topcatModel.
+     * Constructs a query window which on completion will add a new column.
      *
-     * @return  whether a column was successfully added
+     * @param   tcModel      model containing the table data
+     * @param   insertIndex  the default position for the new column
+     * @param   parent       the parent window for this dialogue (used for
+     *                       window positioning)
+     * @return   a window ready for user interaction 
      */
-    protected boolean perform() {
-        SyntheticColumn col = makeColumn();
-        if ( col == null ) {
-            return false;
-        }
-        else {
-            tcModel.appendColumn( col, getIndex() );
-            return true;
+    public static SyntheticColumnQueryWindow
+            newColumnDialog( TopcatModel tcModel, int insertIndex,
+                             Component parent ) {
+        return new SyntheticColumnQueryWindow( tcModel, insertIndex, true,
+                                               parent ) {
+            public boolean perform() {
+                SyntheticColumn col = makeColumn();
+                if ( col == null ) {
+                    return false;
+                }
+                else {
+                    tcModel.appendColumn( col, getIndex() );
+                    return true;
+                }
+            }
+        };
+    }
+
+    /**
+     * Constructs a query window which will edit an existing column in the
+     * model.
+     *
+     * @param  tcModel  topcat model
+     * @param  icol     model index of column to edit
+     * @param  parent   parent window, used for positioning
+     * @param  onChange   callback to be run on the EDT;
+     *                    the boolean parameter will be true only if the
+     *                    expression defining a (synthetic) column has changed
+     * @return    window ready for user interaction
+     */
+    public static SyntheticColumnQueryWindow
+            editColumnDialog( TopcatModel tcModel, int icol, Component parent,
+                              Consumer<Boolean> onChange ) {
+        PlasticStarTable dataModel = tcModel.getDataModel();
+        TableColumnModel colModel = tcModel.getColumnModel();
+        ColumnData cdata = dataModel.getColumnData( icol );
+        ColumnInfo cinfo = cdata.getColumnInfo();
+        SyntheticColumn synthCol = cdata instanceof SyntheticColumn
+                                 ? (SyntheticColumn) cdata
+                                 : null;
+        int ipos = getPositionIndex( colModel, icol );
+        SyntheticColumnQueryWindow qwin =
+                new SyntheticColumnQueryWindow( tcModel, ipos, false, parent ) {
+            public boolean perform() {
+                String expr = getExpression();
+                final boolean expressionChanged;
+                if ( synthCol == null ||
+                     synthCol.getExpression().equals( expr ) ) {
+                    expressionChanged = false;
+                }
+                else {
+                    if ( TopcatJELUtils
+                        .isColumnReferenced( tcModel, icol, expr ) ) {
+                        String[] msg = new String[] {
+                            "Recursive column expression disallowed:",
+                            "\"" + expr + "\"" +
+                            " directly or indirectly references column " +
+                            cinfo.getName(),
+                        };
+                        JOptionPane
+                       .showMessageDialog( this, msg, "Expression Error",
+                                           JOptionPane.ERROR_MESSAGE );
+                        return false;
+                    }
+                    try {
+                        synthCol.setExpression( expr, (Class<?>) null );
+                    }
+                    catch ( CompilationException e ) {
+                        String[] msg = new String[] {
+                            "Syntax error in synthetic column expression \"" +
+                            expr + "\":",
+                            e.getMessage(),
+                        };
+                        JOptionPane
+                       .showMessageDialog( this, msg,
+                                           "Expression Syntax Error",
+                                           JOptionPane.ERROR_MESSAGE );
+                        return false;
+                    }
+                    expressionChanged = true;
+                }
+                cinfo.setName( getColumnName() );
+                cinfo.setUnitString( getUnit() );
+                cinfo.setDescription( getDescription() );
+                cinfo.setUCD( getUCD() );
+                onChange.accept( Boolean.valueOf( expressionChanged ) );
+                int posIndex0 = getPositionIndex( colModel, icol );
+                int posIndex1 = getIndex();
+                if ( posIndex0 >= 0 && posIndex0 != posIndex1 ) {
+                    colModel.moveColumn( posIndex0, posIndex1 );
+                }
+                return true;
+            }
+        };
+        qwin.setColumnName( cinfo.getName() );
+        qwin.setUnit( cinfo.getUnitString() );
+        qwin.setDescription( cinfo.getDescription() );
+        qwin.setUCD( cinfo.getUCD() );
+        if ( synthCol != null ) {
+            qwin.setExpression( synthCol.getExpression() );
         }
+        qwin.expressionField_.setEnabled( synthCol != null );
+        return qwin;
     }
 
     /**
@@ -285,9 +383,10 @@ public class SyntheticColumnQueryWindow extends QueryWindow {
      * @param  parent   parent window, used for positioning
      * @return   a window ready for user interaction 
      */
-    public static SyntheticColumnQueryWindow replaceColumnDialog(
-            final TopcatModel tcModel, final StarTableColumn baseCol,
-            Component parent ) {
+    public static SyntheticColumnQueryWindow
+            replaceColumnDialog( final TopcatModel tcModel,
+                                 final StarTableColumn baseCol,
+                                 Component parent ) {
         final String OLD_SUFFIX = "_old";
         final ColumnList columnList = tcModel.getColumnList();
         final ColumnInfo baseInfo = baseCol.getColumnInfo();
@@ -295,7 +394,7 @@ public class SyntheticColumnQueryWindow extends QueryWindow {
             TopcatUtils.getBaseName( baseInfo.getName(), OLD_SUFFIX );
         int pos = columnList.getModelIndex( columnList.indexOf( baseCol ) );
         SyntheticColumnQueryWindow qwin = 
-            new SyntheticColumnQueryWindow( tcModel, pos, parent ) {
+            new SyntheticColumnQueryWindow( tcModel, pos, true, parent ) {
                 protected boolean perform() {
 
                     /* Create a new column based on the current state of this
@@ -343,8 +442,23 @@ public class SyntheticColumnQueryWindow extends QueryWindow {
         if ( colId != null ) {
             qwin.setExpression( colId.getValue().toString() );
         }
-        qwin.setVisible( true );
         return qwin;
     }
 
+    /**
+     * Returns the position in a given column model at which a column with
+     * a given model index appears.
+     *
+     * @param  colModel  column model
+     * @param  icol   target model index
+     * @return  index in column model of target column, or -1 if not found
+     */
+    private static int getPositionIndex( TableColumnModel colModel, int icol ) {
+        for ( int ic = 0; ic < colModel.getColumnCount(); ic++ ) {
+            if ( colModel.getColumn( ic ).getModelIndex() == icol ) {
+                return ic;
+            }
+        }
+        return -1;
+    }
 }
