@@ -66,7 +66,7 @@ public class TableViewerWindow extends AuxWindow {
     private final TableColumnModel dummyColModel_;
     private final PropertyChangeListener viewbaseListener_;
     private final TableRowHeader rowHeader_;
-    private final ColumnSearchWindow searchWindow_;
+    private final DataColumnSearchWindow searchWindow_;
     private final JLabel nvisLabel_;
     private final JLabel nselLabel_;
     private RowManager rowManager_;
@@ -192,7 +192,7 @@ public class TableViewerWindow extends AuxWindow {
         final Action excludeAct = new SelectionSubsetAction( false );
 
         /* Prepare cell search action. */
-        searchWindow_ = new ColumnSearchWindow( this, tcModel );
+        searchWindow_ = new DataColumnSearchWindow( this );
         Action searchAct = new BasicAction( "Search Column",
                                             ResourceIcon.SEARCH,
                                             "Search for value in cell" ) {
@@ -345,6 +345,15 @@ public class TableViewerWindow extends AuxWindow {
         addHelp( "TableViewerWindow" );
     }
 
+    /**
+     * Returns the model whose data this window is viewing.
+     *
+     * @return  topcat model
+     */
+    public TopcatModel getTopcatModel() {
+        return tcModel_;
+    }
+
     /**
      * Returns the row selection model for this window's JTable.
      *
@@ -476,7 +485,8 @@ public class TableViewerWindow extends AuxWindow {
                                  " with new synthetic column" ) {
                     public void actionPerformed( ActionEvent evt ) {
                         SyntheticColumnQueryWindow
-                           .replaceColumnDialog( tcModel_, tcol, parent );
+                           .replaceColumnDialog( tcModel_, tcol, parent )
+                           .setVisible( true );
                     }
                 };
             replacecolAct.setEnabled( TopcatUtils.canJel() );
@@ -488,7 +498,8 @@ public class TableViewerWindow extends AuxWindow {
             new BasicAction( "New Synthetic Column", ResourceIcon.ADD,
                              "Add new synthetic column after " + colName ) {
                 public void actionPerformed( ActionEvent evt ) {
-                    new SyntheticColumnQueryWindow( tcModel_, jcol + 1, parent )
+                    SyntheticColumnQueryWindow
+                   .newColumnDialog( tcModel_, jcol + 1, parent )
                    .setVisible( true );
                 }
             };
@@ -522,7 +533,7 @@ public class TableViewerWindow extends AuxWindow {
         }
 
         /* Action to search for a string. */
-        if ( ! rowHead && searchWindow_.canSearchColumn( colInfo ) ) {
+        if ( ! rowHead && DataColumnSearchWindow.canSearchColumn( colInfo ) ) {
             Action searchAct =
                 new BasicAction( "Search Column", ResourceIcon.SEARCH,
                                  "Search column for cell content" ) {
