@@ -5,7 +5,6 @@ import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.List;
 import java.util.HashMap;
-import java.util.Iterator;
 import java.util.Map;
 import java.util.logging.Level;
 import java.util.logging.Logger;
@@ -145,16 +144,11 @@ public class TopcatCodec1 implements TopcatCodec {
 
         /* Copy parameters from the input table.
          * Be paranoid about possible name clashes. */
-        for ( Iterator it = dataModel.getParameters().iterator();
-              it.hasNext(); ) {
-            Object item = it.next();
-            if ( item instanceof DescribedValue ) {
-                DescribedValue dval = (DescribedValue) item;
-                String name = dval.getInfo().getName();
-                String utype = dval.getInfo().getUtype();
-                if ( ! isCodecUtype( utype ) ) {
-                    paramList.add( dval );
-                }
+        for ( DescribedValue dval : dataModel.getParameters() ) {
+            String name = dval.getInfo().getName();
+            String utype = dval.getInfo().getUtype();
+            if ( ! isCodecUtype( utype ) ) {
+                paramList.add( dval );
             }
         }
 
@@ -320,7 +314,7 @@ public class TopcatCodec1 implements TopcatCodec {
      * @param   clazz  class of value which will be stored under this item
      * @return   new metadata description object
      */
-    private static ValueInfo createCodecInfo( String name, Class clazz ) {
+    private static ValueInfo createCodecInfo( String name, Class<?> clazz ) {
         DefaultValueInfo info =
             new DefaultValueInfo( CODEC_NAME_PREFIX + name, clazz );
         info.setUtype( CODEC_UTYPE_PREFIX + name );
@@ -401,7 +395,7 @@ public class TopcatCodec1 implements TopcatCodec {
     private RowSubset createRowSubset( String name, final StarTable table,
                                        final int icol, int iflag ) {
         ColumnInfo info = table.getColumnInfo( icol );
-        Class clazz = info.getContentClass();
+        Class<?> clazz = info.getContentClass();
         if ( clazz == Short.class ) {
             final short mask = (short) ( 1 << iflag );
             return new RowSubset( name ) {
@@ -481,9 +475,7 @@ public class TopcatCodec1 implements TopcatCodec {
             codecParamMap_ = new HashMap<String,DescribedValue>();
             List<DescribedValue> dataParamList =
                 new ArrayList<DescribedValue>();
-            for ( Iterator it = inTable.getParameters().iterator();
-                  it.hasNext(); ) {
-                DescribedValue param = (DescribedValue) it.next();
+            for ( DescribedValue param : inTable.getParameters() ) {
                 String utype = param.getInfo().getUtype();
                 if ( isCodecUtype( utype ) ) {
                     codecParamMap_.put( utype, param );
@@ -545,7 +537,7 @@ public class TopcatCodec1 implements TopcatCodec {
              * but we need to return the value in the form requested
              * by the supplied info argument, since it will get cast
              * to that class. */
-            Class infoClazz = info.getContentClass();
+            Class<?> infoClazz = info.getContentClass();
             if ( value == null || infoClazz.isInstance( value ) ) {
                 return value;
             }
