@@ -62,7 +62,6 @@ public class TopcatTapTableLoadDialog extends TapTableLoadDialog {
     private AdqlExample[] uploadExamples_;
     private UrlHandler urlHandler_;
     private double[] skypos_;
-    private TapQueryPanel tqp_;
     private volatile DeletionPolicy deletionPolicy_;
 
     private static final Logger logger_ =
@@ -79,14 +78,18 @@ public class TopcatTapTableLoadDialog extends TapTableLoadDialog {
         Component comp = super.createQueryComponent();
         adjuster_.adjustComponent();
 
-        /* Add menu for TAP-specific items. */
+        /* Add menus for TAP-specific items. */
         List<JMenu> menuList =
             new ArrayList<JMenu>( Arrays.asList( super.getMenus() ) );
+        int imenu = 0;
         JMenu tapMenu = new JMenu( "TAP" );
         tapMenu.setMnemonic( KeyEvent.VK_T );
-        menuList.add( 0, tapMenu );
+        menuList.add( imenu++, tapMenu );
+        JMenu authMenu = new JMenu( "Authentication" );
+        authMenu.setMnemonic( KeyEvent.VK_A );
+        menuList.add( imenu++, authMenu );
         JMenu regMenu = new JMenu( "Registry" );
-        menuList.add( 1, regMenu );
+        menuList.add( imenu++, regMenu );
         setMenus( menuList.toArray( new JMenu[ 0 ] ) );
 
         /* Add reload action. */
@@ -238,6 +241,10 @@ public class TopcatTapTableLoadDialog extends TapTableLoadDialog {
         codingButton.setSelected( true );
         tapMenu.add( codingButton );
 
+        /* Add items to authentication menu. */
+        authMenu.add( getAuthenticateAction() );
+        authMenu.add( ControlWindow.getInstance().getAuthResetAction() );
+
         /* Add items to registry menu. */
         RegistryPanel regPanel = getRegistryPanel();
         if ( regPanel != null ) {
@@ -349,13 +356,13 @@ public class TopcatTapTableLoadDialog extends TapTableLoadDialog {
 
     @Override
     protected TapQueryPanel createTapQueryPanel() {
-        tqp_ = new TapQueryPanel( urlHandler_ ) {
+        TapQueryPanel tqp = new TapQueryPanel( urlHandler_ ) {
             @Override
             public double[] getSkyPos() {
                 return TopcatTapTableLoadDialog.this.skypos_;
             }
         };
-        tqp_.addCustomExamples( "Upload", getUploadExamples() );
+        tqp.addCustomExamples( "Upload", getUploadExamples() );
 
         /* Make sure the panel is kept up to date with the list of
          * tables known by the application. */
@@ -371,13 +378,13 @@ public class TopcatTapTableLoadDialog extends TapTableLoadDialog {
                 updateTopcatTables();
             }
             private void updateTopcatTables() {
-                if ( tqp_ != null ) {
-                    tqp_.setExtraTables( createTopcatValidatorTables() );
+                if ( tqp != null ) {
+                    tqp.setExtraTables( createTopcatValidatorTables() );
                 }
             }
         } );
-        tqp_.setExtraTables( createTopcatValidatorTables() );
-        return tqp_;
+        tqp.setExtraTables( createTopcatValidatorTables() );
+        return tqp;
     }
 
     /**
