@@ -16,6 +16,7 @@ import uk.ac.starlink.vo.AdqlSyntax;
 import uk.ac.starlink.vo.TableMeta;
 import uk.ac.starlink.vo.TapCapability;
 import uk.ac.starlink.vo.TapCapabilityPanel;
+import uk.ac.starlink.vo.VersionedLanguage;
 
 /**
  * Provides some ADQL examples showing how TOPCAT TAP uploads work.
@@ -62,9 +63,11 @@ public abstract class UploadAdqlExample extends AbstractAdqlExample {
                                    "Upload a table and query all its columns; "
                                  + "not very useful",
                                    tcList ) {
-                public String getText( boolean lineBreaks, String lang,
-                                       TapCapability tcap, TableMeta[] tables,
-                                       TableMeta table, double[] skypos ) {
+                public String getAdqlText( boolean lineBreaks,
+                                           VersionedLanguage lang,
+                                           TapCapability tcap,
+                                           TableMeta[] tables, TableMeta table,
+                                           double[] skypos ) {
                     if ( ! TapCapabilityPanel.canUpload( tcap ) ||
                          tcList.getModel().getSize() < 1 ) {
                         return null;
@@ -77,13 +80,15 @@ public abstract class UploadAdqlExample extends AbstractAdqlExample {
                                    "Upload a local table and join a remote "
                                  + "table with it",
                                    tcList ) {
-                public String getText( boolean lineBreaks, String lang,
-                                       TapCapability tcap, TableMeta[] tables,
-                                       TableMeta table, double[] skypos ) {
+                public String getAdqlText( boolean lineBreaks,
+                                           VersionedLanguage lang,
+                                           TapCapability tcap,
+                                           TableMeta[] tables, TableMeta table,
+                                           double[] skypos ) {
                     if ( ! TapCapabilityPanel.canUpload( tcap ) ) {
                         return null;
                     } 
-                    return getJoinText( lineBreaks, lang, tables, table,
+                    return getJoinText( lineBreaks, tcap, lang, tables, table,
                                         tcList );
                 }
             },
@@ -95,12 +100,13 @@ public abstract class UploadAdqlExample extends AbstractAdqlExample {
      *
      * @param  lineBreaks  whether output ADQL should include multiline
      *                     formatting
-     * @param  lang  ADQL language variant (e.g. "ADQL-2.0")
+     * @param  lang  ADQL language variant
      * @param  tables  table metadata set
      * @param  table  currently selected table
      * @param  tcList  JList of known TopcatModels
      */
-    private static String getTrivialText( boolean lineBreaks, String lang,
+    private static String getTrivialText( boolean lineBreaks,
+                                          VersionedLanguage lang,
                                           TableMeta[] tables, TableMeta table,
                                           JList<TopcatModel> tcList ) {
         TopcatModel tcModel = tcList.getSelectedValue();
@@ -110,12 +116,11 @@ public abstract class UploadAdqlExample extends AbstractAdqlExample {
         int tcid = tcModel.getID();
         StringBuffer sbuf = new StringBuffer();
         Breaker breaker = createBreaker( lineBreaks );
-        sbuf.append( "SELECT" )
-            .append( breaker.level( 1 ) )
+        sbuf.append( "SELECT " )
             .append( "TOP " )
             .append( 1000 )
             .append( " *" )
-            .append( breaker.level( 1 ) )
+            .append( breaker.space( 0 ) )
             .append( "FROM " )
             .append( "TAP_UPLOAD.t" )
             .append( tcid );
@@ -127,12 +132,14 @@ public abstract class UploadAdqlExample extends AbstractAdqlExample {
      *
      * @param  lineBreaks  whether output ADQL should include multiline
      *                     formatting
-     * @param  lang  ADQL language variant (e.g. "ADQL-2.0")
+     * @param  tcap  table capabilities for service
+     * @param  lang  ADQL language variant
      * @param  tables  table metadata set
      * @param  table  currently selected table
      * @param  tcList  JList of known TopcatModels
      */
-    private static String getJoinText( boolean lineBreaks, String lang,
+    private static String getJoinText( boolean lineBreaks, TapCapability tcap,
+                                       VersionedLanguage lang,
                                        TableMeta[] tables, TableMeta table,
                                        JList<TopcatModel> tcJlist ) {
         AdqlSyntax syntax = AdqlSyntax.getInstance();
@@ -171,47 +178,57 @@ public abstract class UploadAdqlExample extends AbstractAdqlExample {
         Breaker breaker = createBreaker( lineBreaks );
         String localAlias = "tc";
         String remoteAlias = "db";
-        return new StringBuffer()
-            .append( "SELECT" )
-            .append( breaker.level( 1 ) )
+        String radiusTxt = "5./3600.";
+        StringBuffer sbuf = new StringBuffer();
+        sbuf.append( "SELECT " )
             .append( "TOP " )
             .append( 1000 )
-            .append( breaker.level( 1 ) )
+            .append( breaker.space( 7 ) )
             .append( "*" )
-            .append( breaker.level( 1 ) )
+            .append( breaker.space( 0 ) )
             .append( "FROM " )
             .append( rdRemote.getTable().getName() )
             .append( " AS " )
             .append( remoteAlias )
-            .append( breaker.level( 1 ) )
+            .append( breaker.space( 0 ) )
             .append( "JOIN " )
             .append( "TAP_UPLOAD.t" )
             .append( localRd.getID() )
             .append( " AS " )
             .append( localAlias )
-            .append( breaker.level( 1 ) )
-            .append( "ON 1=CONTAINS(POINT('ICRS', " )
-            .append( remoteAlias )
-            .append( "." )
-            .append( rdRemote.getColumns()[ 0 ] )
-            .append( ", " )
-            .append( remoteAlias )
-            .append( "." )
-            .append( rdRemote.getColumns()[ 1 ] )
-            .append( ")," )
-            .append( breaker.level( 1 ) )
-            .append( "              CIRCLE('ICRS', " )
-            .append( localAlias )
-            .append( "." )
-            .append( localCoords[ 0 ] )
-            .append( ", " )
-            .append( localAlias )
-            .append( "." )
-            .append( localCoords[ 1 ] )
-            .append( ", " )
-            .append( "5./3600." )
-            .append( "))" )
-            .toString();
+            .append( breaker.space( 2 ) );
+        String raRemote = remoteAlias + "." + rdRemote.getColumns()[ 0 ];
+        String deRemote = remoteAlias + "." + rdRemote.getColumns()[ 1 ];
+        String raLocal = localAlias + "." + localCoords[ 0 ];
+        String deLocal = localAlias + "." + localCoords[ 1 ];
+        if ( isAdql21( lang ) ) {
+            sbuf.append( "ON DISTANCE(" )
+                .append( raRemote )
+                .append( ", " )
+                .append( deRemote )
+                .append( ", " )
+                .append( raLocal )
+                .append( ", " )
+                .append( deLocal )
+                .append( ") < " )
+                .append( radiusTxt );
+        }
+        else {
+            sbuf.append( "ON 1=CONTAINS(POINT('ICRS', " )
+                .append( raRemote )
+                .append( ", " )
+                .append( deRemote )
+                .append( ")," )
+                .append( breaker.space( 16 ) )
+                .append( "CIRCLE('ICRS', " )
+                .append( raLocal )
+                .append( ", " )
+                .append( deLocal )
+                .append( ", " )
+                .append( radiusTxt )
+                .append( "))" );
+        }
+        return sbuf.toString();
     }
 
     /**
