@@ -19,6 +19,7 @@ import uk.ac.starlink.table.StarTable;
 import uk.ac.starlink.table.gui.LabelledComponentStack;
 import uk.ac.starlink.topcat.ActionForwarder;
 import uk.ac.starlink.topcat.Outcome;
+import uk.ac.starlink.topcat.ResourceInfo;
 import uk.ac.starlink.topcat.ResourceType;
 import uk.ac.starlink.topcat.Safety;
 import uk.ac.starlink.topcat.ServiceParamPanel;
@@ -54,9 +55,19 @@ public class ServiceActivationType implements ActivationType {
 
     public Suitability getSuitability( TopcatModelInfo tinfo ) {
         StarTable table = tinfo.getTopcatModel().getDataModel();
+
+        /* If service descriptors are present, they can be invoked
+         * as per this activation type. */
         if ( LinksDoc.getServiceDescriptors( table ).length > 0 ) {
+
+            /* For a non-links-response table, presumably the intention
+             * is that they can be invoked directly, so mark them Suggested.
+             * For a links-response table, they are probably there to be
+             * referenced by the service_def column rather than to be
+             * invoked directly by the user, so in that case make the
+             * option less prominent (Present). */
             return LinksDoc.isLinksResponse( table, 2 )
-                 ? Suitability.AVAILABLE
+                 ? Suitability.PRESENT
                  : Suitability.SUGGESTED;
         }
         else {
@@ -86,7 +97,10 @@ public class ServiceActivationType implements ActivationType {
         ServiceConfigurator( TopcatModel tcModel ) {
             super( new JPanel( new BorderLayout() ) );
             tcModel_ = tcModel;
-            invokePanel_ = new InvokePanel( UrlOptions.createOptions( null ) );
+            String ctxtTitle =
+                "TOPCAT(" + tcModel.getID() + "): Invoke Service";
+            invokePanel_ =
+                new InvokePanel( UrlOptions.createOptions( null, ctxtTitle ) );
             ServiceDescriptor[] sds =
                 LinksDoc.getServiceDescriptors( tcModel.getDataModel() );
             servicePanel_ = new ServicePanel( sds );
@@ -367,10 +381,23 @@ public class ServiceActivationType implements ActivationType {
          */
         public ResourceType guessResourceType() {
             URL url = null;
-            String ctype = null;
             ServiceDescriptor sd = getServiceDescriptor();
+            String ctype = sd == null ? null : sd.getContentType();
             String standardId = sd == null ? null : sd.getStandardId();
-            return ResourceType.guessResourceType( url, ctype, standardId );
+            return ResourceType.guessResourceType( new ResourceInfo() {
+                public URL getUrl() {
+                    return url;
+                }
+                public String getContentType() {
+                    return ctype;
+                }
+                public String getContentQualifier() {
+                    return null;
+                }
+                public String getStandardId() {
+                    return standardId;
+                }
+            } );
         }
 
         /**
