@@ -5,12 +5,14 @@
 
 package uk.ac.starlink.topcat.func;
 
+import java.awt.Component;
 import java.awt.Desktop;
 import java.io.File;
 import java.io.IOException;
 import java.net.MalformedURLException;
 import java.net.URI;
 import java.net.URL;
+import uk.ac.starlink.topcat.AbstractHtmlPanel;
 import uk.ac.starlink.topcat.Executor;
 import uk.ac.starlink.topcat.HtmlWindow;
 
@@ -63,17 +65,8 @@ public class Browsers {
                 return "Bad URL: " + url;
             }
         }
-        try {
-            getHtmlWindow().setURL( url1 );
-            return url;
-        }
-        catch ( IOException e ) {
-            String msg = e.getMessage();
-            if ( e == null ) {
-                msg = e.toString();
-            }
-            return msg + ": " + url;
-        }
+        getHtmlWindow().setURL( url1 );
+        return url;
     }
 
     /**
@@ -173,7 +166,8 @@ public class Browsers {
      */
     private static HtmlWindow getHtmlWindow() {
         if ( htmlWindow_ == null ) {
-            htmlWindow_ = new HtmlWindow( null );
+            htmlWindow_ = new HtmlWindow( (Component) null,
+                                          AbstractHtmlPanel.createPanel() );
         }
         if ( ! htmlWindow_.isShowing() ) {
             htmlWindow_.setVisible( true );
