@@ -21,6 +21,7 @@ import uk.ac.starlink.util.gui.ShrinkWrapper;
 import uk.ac.starlink.vo.Capability;
 import uk.ac.starlink.vo.ConeSearch;
 import uk.ac.starlink.vo.ConeVerbosity;
+import uk.ac.starlink.vo.RegistryPanel;
 
 /**
  * DalMultiWindow subclass for Cone Search services.
@@ -45,9 +46,8 @@ public class ConeMultiWindow extends DalMultiWindow {
      */
     private static class ConeMultiService implements DalMultiService {
 
-        @SuppressWarnings({"unchecked","rawtypes"})
-        private final JComboBox verbSelector_ =
-            new JComboBox( ConeVerbosity.getOptions() );
+        private final JComboBox<ConeVerbosity> verbSelector_ =
+            new JComboBox<>( ConeVerbosity.getOptions() );
 
         private final JComponent controlBox_;
 
@@ -109,9 +109,17 @@ public class ConeMultiWindow extends DalMultiWindow {
             return controlBox_;
         }
 
+        public JComponent getVersionComponent() {
+            return null;
+        }
+
+        public void init( RegistryPanel regPanel ) {
+        }
+
         public ConeSearcher createSearcher( URL url, StarTableFactory tfact,
                                             ContentCoding coding ) {
-            int verb = ((ConeVerbosity) verbSelector_.getSelectedItem())
+            int verb = verbSelector_
+                      .getItemAt( verbSelector_.getSelectedIndex() )
                       .getLevel();
             return new ServiceConeSearcher( new ConeSearch( url.toString(),
                                                             coding ),
