@@ -20,6 +20,7 @@ import uk.ac.starlink.ttools.plot2.PlotLayer;
 import uk.ac.starlink.ttools.plot2.PlotUtil;
 import uk.ac.starlink.ttools.plot2.Plotter;
 import uk.ac.starlink.ttools.plot2.ReportMap;
+import uk.ac.starlink.ttools.plot2.Surface;
 import uk.ac.starlink.ttools.plot2.SurfaceFactory;
 import uk.ac.starlink.ttools.plot2.config.ConfigKey;
 import uk.ac.starlink.ttools.plot2.config.ConfigMap;
@@ -238,11 +239,8 @@ public abstract class AxisController<P,A> implements Configger {
     protected void addAspectConfigTab( String label,
                                        Specifier<ConfigMap> aspectSpecifier ) {
         ActionSpecifierPanel aspectPanel =
-                new ActionSpecifierPanel( aspectSpecifier ) {
-            protected void doSubmit( ActionEvent evt ) {
-                setAspect( null );
-            }
-        };
+                new ActionSpecifierPanel( aspectSpecifier );
+        aspectPanel.addActionListener( evt -> setAspect( null ) );
         aspectPanels_.add( aspectPanel );
         mainControl_.addSpecifierTab( label, aspectPanel );
     }
@@ -319,6 +317,22 @@ public abstract class AxisController<P,A> implements Configger {
     public void submitReports( Map<LayerId,ReportMap> reports ) {
     }
 
+    /**
+     * Accepts information about the latest plotting surface to be plotted
+     * by the panel associated with this controller.
+     * This method is intended for passing information back to this controller,
+     * which does not otherwise have access to the asynchronously constructed
+     * Surface object it has configured,
+     * it is not an instruction to adjust the current state.
+     *
+     * <p>The default implementation does nothing, but subclasses may
+     * override it to acquire information about plot state.
+     *
+     * @param  surface  latest plotting surface.
+     */
+    public void setLatestSurface( Surface surface ) {
+    }
+
     /**
      * Indicates whether a new configuration should result in clearing
      * the current ranges and plot aspect.
@@ -442,7 +456,7 @@ public abstract class AxisController<P,A> implements Configger {
      */
     @Equality
     private static class DataId {
-        private final DataGeom geom_;
+        private final String geomVariant_;
         private final StarTable srcTable_;
         private final Object[] coordIds_; 
         private final Object styleKey_;
@@ -457,10 +471,15 @@ public abstract class AxisController<P,A> implements Configger {
          */
         DataId( DataGeom geom, DataSpec dataSpec, CoordGroup cgrp,
                 Object styleKey ) {
-            geom_ = geom;
             srcTable_ = dataSpec.getSourceTable();
             styleKey_ = styleKey;
 
+            /* Use the variant name of the DataGeom rather than the DataGeom's
+             * identity itself.  This is a bit of a hack, but it means that
+             * DataGeoms having the same name can be used to indicate they
+             * are similar enough to each other not to trigger a re-range. */
+            geomVariant_ = geom == null ? null : geom.getVariantName();
+
             /* A CoordinateGroup explicitly labels those coordinates that
              * are relevant for ranging.  Use these. */ 
             int[] rcis = cgrp.getRangeCoordIndices( geom );
@@ -472,7 +491,7 @@ public abstract class AxisController<P,A> implements Configger {
         @Override
         public int hashCode() {
             int code = 33771;
-            code = 23 * code + PlotUtil.hashCode( geom_ );
+            code = 23 * code + PlotUtil.hashCode( geomVariant_ );
             code = 23 * code + srcTable_.hashCode();
             code = 23 * code + Arrays.hashCode( coordIds_ );
             code = 23 * code + PlotUtil.hashCode( styleKey_ );
@@ -482,7 +501,7 @@ public abstract class AxisController<P,A> implements Configger {
         public boolean equals( Object o ) {
             if ( o instanceof DataId ) {
                 DataId other = (DataId) o;
-                return PlotUtil.equals( this.geom_, other.geom_ )
+                return PlotUtil.equals( this.geomVariant_, other.geomVariant_ )
                     && this.srcTable_.equals( other.srcTable_ )
                     && Arrays.equals( this.coordIds_, other.coordIds_ )
                     && PlotUtil.equals( this.styleKey_, other.styleKey_ );
