@@ -32,7 +32,6 @@ import uk.ac.starlink.ttools.plot2.PlotUtil;
 import uk.ac.starlink.ttools.plot2.config.ConfigKey;
 import uk.ac.starlink.ttools.plot2.config.ConfigMap;
 import uk.ac.starlink.ttools.plot2.data.Coord;
-import uk.ac.starlink.ttools.plot2.data.FloatingArrayCoord;
 import uk.ac.starlink.ttools.plot2.data.Input;
 import uk.ac.starlink.ttools.plot2.data.InputMeta;
 import uk.ac.starlink.util.gui.ComboBoxBumper;
@@ -50,6 +49,7 @@ public class CoordPanel {
     private final ConfigSpecifier cspec_;
     private final ActionForwarder forwarder_;
     private final List<List<ColumnDataComboBox>> colSelectors_;
+    private final CoordStack stack_;
     private final JComponent panel_;   
     private final JComponent controlBox_;
     private TopcatModel tcModel_;
@@ -60,18 +60,23 @@ public class CoordPanel {
      * @param  coords  coordinate definitions for which values are required
      */
     public CoordPanel( Coord[] coords ) {
-        this( coords, new ConfigKey<?>[ 0 ] );
+        this( coords, new ConfigKey<?>[ 0 ], createDefaultStack() );
     }
 
     /**
      * Constructs a CoordPanel for selecting Coords and Config values.
+     * For the stack parameter {@link #createDefaultStack} may be used
+     * if there are no special requirements.
      *
      * @param  coords  coordinate definitions for which values are required
      * @param  configKeys   config value keys
+     * @param  stack   coord stack implementation
      */
-    public CoordPanel( Coord[] coords, ConfigKey<?>[] configKeys ) {
+    public CoordPanel( Coord[] coords, ConfigKey<?>[] configKeys,
+                       CoordStack stack ) {
         panel_ = new JPanel( new BorderLayout() );
         coords_ = coords;
+        stack_ = stack;
         forwarder_ = new ActionForwarder();
         controlBox_ = Box.createVerticalBox();
 
@@ -85,7 +90,6 @@ public class CoordPanel {
         /* Place entry components for each required coordinate. */
         int nc = coords.length;
         colSelectors_ = new ArrayList<List<ColumnDataComboBox>>();
-        LabelledComponentStack stack = new LabelledComponentStack();
         for ( int ic = 0; ic < nc; ic++ ) {
             Input[] inputs = coords[ ic ].getInputs();
             int ni = inputs.length;
@@ -117,12 +121,10 @@ public class CoordPanel {
                 size.width = 80;
                 cs.setMinimumSize( size );
                 cs.setPreferredSize( cs.getMinimumSize() );
-                stack.addLine( meta.getLongName(), null, line, true );
+                JLabel label = stack_.addCoordLine( meta.getLongName(), line );
 
                 /* Arrange for the coordinate entry labels to display tooltips
                  * giving the current value in a stilts-friendly format. */
-                JLabel[] labels = stack.getLabels();
-                final JLabel label = labels[ labels.length - 1 ];
                 label.addMouseListener( InstantTipper.getInstance() );
                 final String shortName = meta.getShortName();
                 ActionListener tipListener = new ActionListener() {
@@ -142,7 +144,7 @@ public class CoordPanel {
             }
         }
         if ( nc > 0 ) {
-            controlBox_.add( new LineBox( null, stack, true ) );
+            controlBox_.add( new LineBox( null, stack_.getPanel(), true ) );
         }
 
         /* Place the lot at the top of the component so it doesn't fill
@@ -201,6 +203,15 @@ public class CoordPanel {
         return panel_;
     }
 
+    /**
+     * Returns the component listing all the coordinates.
+     *
+     * @return  coordinate stack
+     */
+    public CoordStack getStack() {
+        return stack_;
+    }
+
     /**
      * Adds a listener which will be notified when the coordinate selection
      * changes.
@@ -226,7 +237,7 @@ public class CoordPanel {
      *
      * @return  action forwarder
      */
-    public ActionListener getActionForwarder() {
+    public ActionForwarder getActionForwarder() {
         return forwarder_;
     }
 
@@ -247,16 +258,16 @@ public class CoordPanel {
     public void setTable( TopcatModel tcModel, boolean autoPopulate ) {
         tcModel_ = tcModel;
         int is = 1;
-        int ninRequired = 0;
+        int ninPreferred = 0;
         int ninPopulated = 0;
         for ( int ic = 0; ic < coords_.length; ic++ ) {
             List<ColumnDataComboBox> colsels = colSelectors_.get( ic );
             Coord coord = coords_[ ic ];
-            boolean isReq = isRequiredCoord( coord );
+            boolean isPref = isPreferredCoord( coord );
             Input[] inputs = coord.getInputs();
             int ni = colsels.size();
-            if ( isReq ) {
-                ninRequired += ni;
+            if ( isPref ) {
+                ninPreferred += ni;
             }
             for ( int ii = 0; ii < ni; ii++ ) {
                 InputMeta meta = inputs[ ii ].getMeta();
@@ -295,7 +306,7 @@ public class CoordPanel {
                         }
                         if ( cdata != null ) {
                             model.setSelectedItem( cdata );
-                            if ( isReq ) {
+                            if ( isPref ) {
                                 ninPopulated++;
                             }
                         }
@@ -307,7 +318,7 @@ public class CoordPanel {
         /* Autopopulate only if none of the existing columns can be used.  
          * There are other possibilities, such as autopopulating those
          * columns which can't be re-used, but for now keep it simple. */
-        if ( autoPopulate && ninPopulated == 0 && ninRequired > 0 ) {
+        if ( autoPopulate && ninPopulated == 0 && ninPreferred > 0 ) {
             autoPopulate();
         }
     }
@@ -419,6 +430,43 @@ public class CoordPanel {
         colSelectors_.get( ic ).get( iu ).setModel( model );
     }
 
+    /**
+     * Indicates whether a coordinate is one that ought to get filled in
+     * if possible.
+     * The CoordPanel implementation simply returns
+     * coord.{@link uk.ac.starlink.ttools.plot2.data.Coord#isRequired},
+     * but subclasses can override this if more nuanced behaviour is necessary.
+     *
+     * <p>In particular in order for autopopulation to work correctly,
+     * it may be necessary to return true for all members of a group of
+     * coordinates for which at least one has to be filled in
+     * for a viable plot.
+     *
+     * @param  coord   candidate coordinate
+     * @return  true if we should try hard to get a value
+     */
+    public boolean isPreferredCoord( Coord coord ) {
+        return coord.isRequired();
+    }
+
+    /**
+     * Returns a list of coordinates which do not correspond to the
+     * selectors displayed here, but which should not be acquired by
+     * other means.
+     *
+     * <p>This is a hack to work round situations when coordinates are
+     * added into results by non-obvious means.  In most cases
+     * the output result will be an empty array, which is what the
+     * implementation in this class does.  But subclasses can override
+     * it for special behaviour.
+     *
+     * @return   list of coords which this panel will arrange to provide
+     *           values for in some non-standard way
+     */
+    public Coord[] getAdditionalManagedCoords() {
+        return new Coord[ 0 ];
+    }
+
     /**
      * Returns a list of column metadata items for the items in a
      * list model of columns.
@@ -450,7 +498,7 @@ public class CoordPanel {
      * @return  true if selection was successfully performed
      */
     public static boolean populate( ColumnDataComboBoxModel model,
-                                     ValueInfo info ) {
+                                    ValueInfo info ) {
         for ( int i = 0; i < model.getSize(); i++ ) {
             ColumnData cdata = model.getColumnDataAt( i );
             if ( cdata != null &&
@@ -462,6 +510,25 @@ public class CoordPanel {
         return false;
     }
 
+    /**
+     * Returns a CoordStack implementation suitable for general-purpose use.
+     *
+     * @return  new coord stack 
+     */
+    public static CoordStack createDefaultStack() {
+        final LabelledComponentStack lstack = new LabelledComponentStack();
+        return new CoordStack() {
+            public JComponent getPanel() {
+                return lstack;
+            }
+            public JLabel addCoordLine( String labelTxt, JComponent line ) {
+                lstack.addLine( labelTxt, null, line, true );
+                JLabel[] labels = lstack.getLabels();
+                return labels[ labels.length - 1 ];
+            }
+        };
+    }
+
     /**
      * Indicates whether two infos match.
      * The criterion is that both name and UCD are the same.
@@ -475,28 +542,6 @@ public class CoordPanel {
             && PlotUtil.equals( info1.getUCD(), info2.getUCD() );
     }
 
-    /**
-     * Indicates whether a coordinate is one that ought to get filled in
-     * if possible.
-     *
-     * @param  coord   candidate coordinate
-     * @return  true if we should try hard to get a value
-     */
-    private static boolean isRequiredCoord( Coord coord ) {
-
-        /* This is hacky.  The isRequired() method defines the basic behaviour,
-         * but the FloatingArrayCoord X and Y coordinates are a special case;
-         * at least one or other should be filled in, but neither is actually
-         * mandatory.  Moreover, the behaviour here is necessary at present
-         * to ensure that autopopulation works as desired (pulling out array
-         * values from table parameters) for the fairly common case of
-         * spectra with fluxes in a column but fixed wavelength arrays;
-         * see XYArrayCoordPanel. */
-        return coord.isRequired()
-            || coord.equals( FloatingArrayCoord.X )
-            || coord.equals( FloatingArrayCoord.Y );
-    }
-
     /**
      * Returns the index of an entry in a column selector suitable for
      * use as an example plotting coordinate.
@@ -532,4 +577,29 @@ public class CoordPanel {
         }
         return is;
     }
+
+    /**
+     * Interface for presenting a list of coordinate selection components.
+     * The term "stack" here is used in a simply visual sense.
+     * @see  #createDefaultStack
+     */
+    public static interface CoordStack {
+
+        /**
+         * Adds a labelled line to the stack of components.
+         *
+         * @param  labelTxt  text of displayed label to associate with the
+         *                   component
+         * @param  line   component to add
+         * @return   label component displaying supplied <code>labelTxt</code>
+         */
+        JLabel addCoordLine( String labelTxt, JComponent line );
+
+        /**
+         * Returns the visual component displaying this stack.
+         *
+         * @return  panel for user interaction
+         */
+        JComponent getPanel();
+    }
 }
