@@ -29,13 +29,11 @@ import uk.ac.starlink.topcat.ResourceIcon;
 import uk.ac.starlink.topcat.RowSubset;
 import uk.ac.starlink.topcat.TopcatModel;
 import uk.ac.starlink.ttools.plot.Range;
-import uk.ac.starlink.ttools.plot2.GangerFactory;
 import uk.ac.starlink.ttools.plot2.PlotLayer;
 import uk.ac.starlink.ttools.plot2.PlotType;
 import uk.ac.starlink.ttools.plot2.PlotUtil;
 import uk.ac.starlink.ttools.plot2.Plotter;
 import uk.ac.starlink.ttools.plot2.ReportMap;
-import uk.ac.starlink.ttools.plot2.SingleGanger;
 import uk.ac.starlink.ttools.plot2.Surface;
 import uk.ac.starlink.ttools.plot2.config.ConfigKey;
 import uk.ac.starlink.ttools.plot2.data.FloatingCoord;
@@ -72,7 +70,8 @@ public class HistogramPlotWindow
              extends StackPlotWindow<PlaneSurfaceFactory.Profile,PlaneAspect> {
 
     private static final PlanePlotType PLOT_TYPE =
-        new PlanePlotType( createHistogramPlotters(), false );
+        new PlanePlotType( HistogramAxisController.HISTOGRAM_SURFACE_FACTORY,
+                           createHistogramPlotters() );
     private static final HistogramPlotTypeGui PLOT_GUI =
         new HistogramPlotTypeGui();
     private static final int BINS_TABLE_INTRO_NCOL = 2;
@@ -389,7 +388,7 @@ public class HistogramPlotWindow
             PlotUtil.padRange( yrange, ylogFlag );
             double[] ybounds = yrange.getFiniteBounds( ylogFlag );
             PlaneAspect aspect = new PlaneAspect( xbounds, ybounds );
-            getAxisController( iz ).setAspect( aspect );
+            getZoneController( iz ).setAspect( aspect );
             plotPanel.replot();
         }
     }
@@ -482,9 +481,10 @@ public class HistogramPlotWindow
      */
     private static class HistogramPlotTypeGui
             implements PlotTypeGui<PlaneSurfaceFactory.Profile,PlaneAspect> {
-        public AxisController<PlaneSurfaceFactory.Profile,PlaneAspect>
-                createAxisController() {
-            return new HistogramAxisController();
+        public AxesController<PlaneSurfaceFactory.Profile,PlaneAspect>
+                createAxesController() {
+            return SingleAdapterAxesController
+                  .create( new HistogramAxisController() );
         }
         public PositionCoordPanel createPositionCoordPanel( int npos ) {
             return SimplePositionCoordPanel
@@ -494,9 +494,8 @@ public class HistogramPlotWindow
         public PositionCoordPanel createAreaCoordPanel() {
             throw new UnsupportedOperationException();
         }
-        public GangerFactory<PlaneSurfaceFactory.Profile,PlaneAspect>
-                getGangerFactory() {
-            return SingleGanger.createFactory( PLOT_TYPE );
+        public ZoneLayerManager createLayerManager( FormLayerControl flc ) {
+            return new SingleZoneLayerManager( flc );
         }
         public ZoneFactory createZoneFactory() {
             return ZoneFactories.FIXED;
@@ -507,12 +506,12 @@ public class HistogramPlotWindow
         public boolean hasPositions() {
             return false;
         }
-        public boolean isPlanar() {
-            return true;
-        }
         public FigureMode[] getFigureModes() {
             return new FigureMode[ 0 ];
         }
+        public boolean hasExtraHistogram() {
+            return false;
+        }
         public String getNavigatorHelpId() {
             return "histogramNavigation";
         }
