@@ -27,11 +27,13 @@ import javax.swing.event.ListSelectionListener;
 import uk.ac.starlink.topcat.ResourceIcon;
 import uk.ac.starlink.topcat.TopcatListener;
 import uk.ac.starlink.topcat.TopcatModel;
+import uk.ac.starlink.ttools.plot2.PlotUtil;
 import uk.ac.starlink.ttools.plot2.Plotter;
 import uk.ac.starlink.ttools.plot2.config.ConfigKey;
 import uk.ac.starlink.ttools.plot2.config.Specifier;
 import uk.ac.starlink.ttools.plot2.data.Coord;
 import uk.ac.starlink.ttools.plot2.layer.HandleArrayForm;
+import uk.ac.starlink.ttools.plot2.layer.HistogramPlotter;
 import uk.ac.starlink.ttools.plot2.layer.ModePlotter;
 
 /**
@@ -59,6 +61,7 @@ public class MultiFormLayerControl extends FormLayerControl {
     /**
      * Constructor.
      *
+     * @param  plotTypeGui   plot type
      * @param  posCoordPanel  panel for entering table and basic positional
      *                        coordinates
      * @param  tablesModel   list of available tables
@@ -74,15 +77,16 @@ public class MultiFormLayerControl extends FormLayerControl {
      * @param  baseConfigger  configuration source for some global config
      *                        options
      */
-    public MultiFormLayerControl( PositionCoordPanel posCoordPanel,
+    public MultiFormLayerControl( PlotTypeGui<?,?> plotTypeGui,
+                                  PositionCoordPanel posCoordPanel,
                                   ListModel<TopcatModel> tablesModel,
                                   Specifier<ZoneId> zsel, boolean autoPopulate,
                                   NextSupplier nextSupplier,
                                   TopcatListener tcListener, Icon controlIcon,
                                   Plotter<?>[] plotters,
                                   Configger baseConfigger ) {
-        super( posCoordPanel, tablesModel, zsel, autoPopulate, nextSupplier,
-               tcListener, controlIcon );
+        super( plotTypeGui, posCoordPanel, tablesModel, zsel, autoPopulate,
+               nextSupplier, tcListener, controlIcon );
         baseConfigger_ = baseConfigger;
         subsetKeys_ = nextSupplier.getKeys();
 
@@ -206,9 +210,10 @@ public class MultiFormLayerControl extends FormLayerControl {
         }
 
         /* Special case hacks for additional default forms.
-         * Currently there's only one, an inactive HandleForm in the case of
-         * the XYArray control.  If more special casing is required in future,
-         * think about generalising this. */
+         * Currently there are only two, but if these become more common
+         * think about generalising this mechanism. */
+
+        /* Make HandleForm inactive in the case of the XYArray control. */
         List<Action> extraDfltActs = new ArrayList<>();
         for ( ModePlotter.Form form : modePlotterMap_.keySet() ) {
             if ( form instanceof HandleArrayForm ) {
@@ -224,6 +229,15 @@ public class MultiFormLayerControl extends FormLayerControl {
             }
         }
 
+        /* Add an additional histogram plot to the list if required. */
+        if ( plotTypeGui.hasExtraHistogram() ) {
+            for ( Plotter<?> plotter : singlePlotterList_ ) {
+                if ( plotter instanceof HistogramPlotter ) {
+                    extraDfltActs.add( new SingleFormAction( plotter ) );
+                }
+            }
+        }
+
         /* Prepare plotters added to control by default. */
         dfltFormActs_ = new ArrayList<>();
         dfltFormActs_.addAll( extraDfltActs );
@@ -371,8 +385,12 @@ public class MultiFormLayerControl extends FormLayerControl {
         List<Coord> extraCoords =
             new ArrayList<Coord>( Arrays.asList( plotter.getCoordGroup()
                                                         .getExtraCoords() ) );
-        extraCoords.removeAll( Arrays.asList( getPositionCoordPanel()
-                                             .getCoords() ) );
+        PositionCoordPanel posCoordPanel = getPositionCoordPanel();
+        Coord[] excludeCoords = PlotUtil.arrayConcat(
+            posCoordPanel.getCoords(),
+            posCoordPanel.getAdditionalManagedCoords()
+        );
+        extraCoords.removeAll( Arrays.asList( excludeCoords ) );
         FormControl fc =
             new SimpleFormControl( baseConfigger_, plotter,
                                    extraCoords.toArray( new Coord[ 0 ] ) );
@@ -387,9 +405,14 @@ public class MultiFormLayerControl extends FormLayerControl {
      * @return   new form control configured for the current table
      */
     private ModeFormControl createModeFormControl( ModePlotter<?>[] plotters ) {
+        PositionCoordPanel posCoordPanel = getPositionCoordPanel();
+        Coord[] excludeCoords = PlotUtil.arrayConcat(
+            posCoordPanel.getCoords(),
+            posCoordPanel.getAdditionalManagedCoords()
+        );
         ModeFormControl fc =
             new ModeFormControl( baseConfigger_, plotters, subsetKeys_,
-                                 getPositionCoordPanel().getCoords() );
+                                 excludeCoords );
         fc.setTable( getTopcatModel(), getSubsetManager(), getSubsetStack() );
         return fc;
     }
