@@ -26,7 +26,7 @@ public class PlaneAxisController
      * Constructor.
      */
     public PlaneAxisController() {
-        super( new PlaneSurfaceFactory( false ), createAxisLabelKeys() );
+        super( new PlaneSurfaceFactory(), createAxisLabelKeys() );
         SurfaceFactory<PlaneSurfaceFactory.Profile,PlaneAspect> surfFact =
             getSurfaceFactory();
         ConfigControl mainControl = getMainControl();
@@ -60,19 +60,32 @@ public class PlaneAxisController
         } );
 
         /* Grid tab. */
-        mainControl.addSpecifierTab( "Grid",
-                                     new ConfigSpecifier( new ConfigKey<?>[] {
-            PlaneSurfaceFactory.GRID_KEY,
-            StyleKeys.GRID_COLOR,
+        List<ConfigKey<?>> gridKeyList = new ArrayList<>();
+        gridKeyList.add( PlaneSurfaceFactory.GRID_KEY );
+        gridKeyList.addAll( Arrays
+                           .asList( StyleKeys.GRIDCOLOR_KEYSET.getKeys() ) );
+        gridKeyList.addAll( Arrays.asList( new ConfigKey<?>[] {
             StyleKeys.AXLABEL_COLOR,
             StyleKeys.MINOR_TICKS,
+            StyleKeys.SHADOW_TICKS,
             PlaneSurfaceFactory.XCROWD_KEY,
             PlaneSurfaceFactory.YCROWD_KEY,
         } ) );
+        ConfigKey<?>[] gridKeys = gridKeyList.toArray( new ConfigKey<?>[ 0 ] );
+        mainControl.addSpecifierTab( "Grid", new ConfigSpecifier( gridKeys ) );
 
         /* Labels tab. */
         addLabelsTab();
 
+        /* Secondary axes tab. */
+        mainControl.addSpecifierTab( "Secondary",
+                                     new ConfigSpecifier( new ConfigKey<?>[] {
+            PlaneSurfaceFactory.X2FUNC_KEY,
+            PlaneSurfaceFactory.X2LABEL_KEY,
+            PlaneSurfaceFactory.Y2FUNC_KEY,
+            PlaneSurfaceFactory.Y2LABEL_KEY,
+        } ) );
+
         /* Font tab. */
         mainControl.addSpecifierTab( "Font",
                                      new ConfigSpecifier( StyleKeys.CAPTIONER
