@@ -12,9 +12,7 @@ import uk.ac.starlink.table.ValueInfo;
 import uk.ac.starlink.topcat.ColumnDataComboBoxModel;
 import uk.ac.starlink.topcat.TopcatModel;
 import uk.ac.starlink.ttools.plot2.DataGeom;
-import uk.ac.starlink.ttools.plot2.GangerFactory;
 import uk.ac.starlink.ttools.plot2.PlotType;
-import uk.ac.starlink.ttools.plot2.SingleGanger;
 import uk.ac.starlink.ttools.plot2.config.ConfigKey;
 import uk.ac.starlink.ttools.plot2.config.Specifier;
 import uk.ac.starlink.ttools.plot2.data.AreaCoord;
@@ -65,9 +63,9 @@ public class SkyPlotWindow
             axisController_ = new SkyAxisController();
         }
 
-        public AxisController<SkySurfaceFactory.Profile,SkyAspect>
-                createAxisController() {
-            return axisController_;
+        public AxesController<SkySurfaceFactory.Profile,SkyAspect>
+                createAxesController() {
+            return SingleAdapterAxesController.create( axisController_ );
         }
 
         public PositionCoordPanel createPositionCoordPanel( int npos ) {
@@ -94,23 +92,18 @@ public class SkyPlotWindow
             };
         }
 
+        public ZoneLayerManager createLayerManager( FormLayerControl flc ) {
+            return new SingleZoneLayerManager( flc );
+        }
+
         public boolean hasPositions() {
             return true;
         }
 
-        public boolean isPlanar() {
-            return false;
-        }
-
         public FigureMode[] getFigureModes() {
             return SkyFigureMode.MODES;
         }
 
-        public GangerFactory<SkySurfaceFactory.Profile,SkyAspect>
-                getGangerFactory() {
-            return SingleGanger.createFactory( PLOT_TYPE );
-        }
-
         public ZoneFactory createZoneFactory() {
             return ZoneFactories.FIXED;
         } 
@@ -119,6 +112,10 @@ public class SkyPlotWindow
             return null;
         }
 
+        public boolean hasExtraHistogram() {
+            return false;
+        }
+
         public String getNavigatorHelpId() {
             return "skyNavigation";
         }
