@@ -4,8 +4,6 @@ import java.awt.Component;
 import javax.swing.ListModel;
 import uk.ac.starlink.topcat.TopcatModel;
 import uk.ac.starlink.ttools.plot2.DataGeom;
-import uk.ac.starlink.ttools.plot2.GangerFactory;
-import uk.ac.starlink.ttools.plot2.SingleGanger;
 import uk.ac.starlink.ttools.plot2.config.ConfigKey;
 import uk.ac.starlink.ttools.plot2.data.AreaCoord;
 import uk.ac.starlink.ttools.plot2.data.Coord;
@@ -44,9 +42,10 @@ public class SpherePlotWindow
      */
     private static class SpherePlotTypeGui
             implements PlotTypeGui<CubeSurfaceFactory.Profile,CubeAspect> {
-        public AxisController<CubeSurfaceFactory.Profile,CubeAspect>
-                createAxisController() {
-            return new CubeAxisController( true );
+        public AxesController<CubeSurfaceFactory.Profile,CubeAspect>
+                createAxesController() {
+            return SingleAdapterAxesController
+                  .create( new CubeAxisController( true ) );
         }
         public PositionCoordPanel createPositionCoordPanel( int npos ) {
             return SimplePositionCoordPanel
@@ -62,25 +61,24 @@ public class SpherePlotWindow
                 }
             };
         }
+        public ZoneLayerManager createLayerManager( FormLayerControl flc ) {
+            return new SingleZoneLayerManager( flc );
+        }
         public boolean hasPositions() {
             return true;
         }
-        public boolean isPlanar() {
-            return false;
-        }
         public FigureMode[] getFigureModes() {
             return new FigureMode[ 0 ];
         }
-        public GangerFactory<CubeSurfaceFactory.Profile,CubeAspect>
-                getGangerFactory() {
-            return SingleGanger.createFactory( PLOT_TYPE );
-        }
         public ZoneFactory createZoneFactory() {
             return ZoneFactories.FIXED;
         } 
         public CartesianRanger getCartesianRanger() {
             return null;
         }
+        public boolean hasExtraHistogram() {
+            return false;
+        }
         public String getNavigatorHelpId() {
             return "sphereNavigation";
         }
