@@ -9,12 +9,10 @@ import uk.ac.starlink.table.TimeDomain;
 import uk.ac.starlink.topcat.ColumnDataComboBoxModel;
 import uk.ac.starlink.topcat.TopcatModel;
 import uk.ac.starlink.ttools.plot2.DataGeom;
-import uk.ac.starlink.ttools.plot2.GangerFactory;
 import uk.ac.starlink.ttools.plot2.PlotType;
 import uk.ac.starlink.ttools.plot2.data.Coord;
 import uk.ac.starlink.ttools.plot2.geom.TimeAspect;
 import uk.ac.starlink.ttools.plot2.geom.TimePlotType;
-import uk.ac.starlink.ttools.plot2.geom.TimeStackGanger;
 import uk.ac.starlink.ttools.plot2.geom.TimeSurfaceFactory;
 
 /**
@@ -46,9 +44,13 @@ public class TimePlotWindow
      */
     private static class TimePlotTypeGui
             implements PlotTypeGui<TimeSurfaceFactory.Profile,TimeAspect> {
-        public AxisController<TimeSurfaceFactory.Profile,TimeAspect>
-                createAxisController() {
-            return new TimeAxisController();
+        public AxesController<TimeSurfaceFactory.Profile,TimeAspect>
+                createAxesController() {
+            return new DisjointAxesController<TimeSurfaceFactory.Profile,
+                                              TimeAspect>(
+                ZoneFactories.createIntegerZoneFactory( true ),
+                TimeAxisController::new
+            );
         }
         public PositionCoordPanel createPositionCoordPanel( final int npos ) {
             final TimeDomain domain = TimeDomain.INSTANCE;
@@ -110,25 +112,24 @@ public class TimePlotWindow
         public PositionCoordPanel createAreaCoordPanel() {
             throw new UnsupportedOperationException();
         }
-        public boolean hasPositions() {
-            return true;
+        public ZoneLayerManager createLayerManager( FormLayerControl flc ) {
+            return new SingleZoneLayerManager( flc );
         }
-        public boolean isPlanar() {
+        public boolean hasPositions() {
             return true;
         }
         public FigureMode[] getFigureModes() {
             return new FigureMode[ 0 ];
         }
-        public GangerFactory<TimeSurfaceFactory.Profile,TimeAspect>
-                getGangerFactory() {
-            return TimeStackGanger.FACTORY;
-        }
         public ZoneFactory createZoneFactory() {
             return ZoneFactories.createIntegerZoneFactory( true );
         }
         public CartesianRanger getCartesianRanger() {
             return null;
         }
+        public boolean hasExtraHistogram() {
+            return false;
+        }
         public String getNavigatorHelpId() {
             return "timeNavigation";
         }
