@@ -19,6 +19,7 @@ import uk.ac.starlink.ttools.jel.JELUtils;
 import uk.ac.starlink.ttools.plot2.Tick;
 import uk.ac.starlink.ttools.plot2.geom.PlanarSurface;
 import uk.ac.starlink.ttools.plot2.geom.PlaneSurface;
+import uk.ac.starlink.ttools.plot2.geom.SideFlags;
 import uk.ac.starlink.util.LogUtils;
 
 public class FigureModeTest extends TestCase {
@@ -45,7 +46,9 @@ public class FigureModeTest extends TestCase {
                                   0.1, 10000, 0.2, 20,   // data coords
                                   xlog, ylog, xflip, yflip,
                                   new Tick[ 0 ], new Tick[ 0 ], "X", "Y",
-                                  null, Color.GRAY, Color.BLACK );
+                                  new Tick[ 0 ], new Tick[ 0 ], null, null,
+                                  null, SideFlags.ALL, Color.GRAY, Color.BLACK,
+                                  false );
             checkPlaneMode( PlaneFigureMode.POLYGON,
                             PlaneFigureMode.OUTSIDE_POLYGON,
                             surf,
